@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b dnode methods class - MDnode class decl.
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef XNODE_H
 #define XNODE_H
 
-static const char * const IDENT_XNODE_H="$Date: 2009-08-08 13:30:21 $";
+#define IDENT_XNODE_H "$Id: xnode.h,v 1.31 2012-03-16 09:24:08 moko Exp $"
 
 class MXnode: public Methoded {
 public: // Value
@@ -47,6 +47,10 @@ private:
 
 xmlNode& as_node(MethodParams& params, int index, const char* msg);
 xmlChar* as_xmlchar(Request& r, MethodParams& params, int index, const char* msg);
+xmlChar* as_xmlqname(Request& r, MethodParams& params, int index, const char* msg=0);
+xmlChar* as_xmlncname(Request& r, MethodParams& params, int index, const char* msg=0);
+xmlChar* as_xmlname(Request& r, MethodParams& params, int index, const char* msg=0);
+xmlChar* as_xmlnsuri(Request& r, MethodParams& params, int index);
 xmlNs& pa_xmlMapNs(xmlDoc& doc, const xmlChar* href, const xmlChar* prefix);
 
 #endif
