@@ -1,14 +1,14 @@
 /** @file
 	Parser: Configure file for autoconf-disabled platforms.
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_CONFIG_FIXED_H
 #define PA_CONFIG_FIXED_H
 
-static const char * const IDENT_CONFIG_FIXED_H="$Date: 2009-12-04 04:20:18 $";
+#define IDENT_PA_CONFIG_FIXED_H "$Id: pa_config_fixed.h,v 1.78 2012-06-19 08:51:09 moko Exp $"
 
 #define inline  __inline
 #define HAVE_ASSERT_H
@@ -27,6 +27,7 @@ static const char * const IDENT_CONFIG_FIXED_H="$Date: 2009-12-04 04:20:18 $";
 #define HAVE_DIRECT_H
 #define HAVE_SETJMP_H
 #define HAVE_MEMORY_H
+#define HAVE_LIMITS_H
 #define HAVE_SYS_LOCKING_H
 #define HAVE_SYS_TYPES_H
 #define HAVE_WINSOCK_H
@@ -59,13 +60,7 @@ static const char * const IDENT_CONFIG_FIXED_H="$Date: 2009-12-04 04:20:18 $";
 #	define LIBEXSLT_STATIC
 #endif
 
-// if no access to console, but need asserts
-//#define PA_RELEASE_ASSERTS
-
-// PCRE
+// otherwise functions in pcre.h will be declared as __declspec(dllimport)
 #define PCRE_STATIC
 
-// with CULR
-#define HAVE_CURL
-
 #endif
