@@ -1,7 +1,7 @@
 /** @file
 	Parser: includes all Configure-d headers
 
-	Copyright (c) 2001-2005 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 
 	when used Configure [HAVE_CONFIG_H] it uses defines from Configure,
@@ -80,6 +80,10 @@
 #	include <string.h>
 #endif
 
+#ifdef HAVE_LIMITS_H
+#include <limits.h>
+#endif
+
 #ifdef HAVE_DIRECT_H
 #	include <direct.h>
 #endif
@@ -213,15 +217,6 @@ inline size_t min(size_t a, size_t b){ return a<b?a:b; }
 // memcpy deprecation
 #pragma warning(disable:4996)
 
-
-#if 0
-#ifdef _DEBUG
-#	define _CRTDBG_MAP_ALLOC
-// When the _CRTDBG_MAP_ALLOC flag is defined in the debug version of an application, 
-// the base version of the heap functions are directly mapped to their debug versions
-#endif
-#endif
-
 #endif
 
 #ifdef PA_RELEASE_ASSERTS
