@@ -1,14 +1,14 @@
 /** @file
 	Parser: commonly used functions.
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_HTTP_H
 #define PA_HTTP_H
 
-static const char * const IDENT_HTTP_H="$Date: 2010-12-29 12:17:58 $";
+#define IDENT_PA_HTTP_H "$Id: pa_http.h,v 1.8 2012-06-20 20:54:25 moko Exp $"
 
 #include "pa_vstring.h"
 #include "pa_vint.h"
@@ -16,19 +16,16 @@ static const char * const IDENT_HTTP_H="$Date: 2010-12-29 12:17:58 $";
 #include "pa_vtable.h"
 #include "pa_socks.h"
 
-#ifdef CYGWIN
-#define _GNU_H_WINDOWS32_SOCKETS
-// for PASCAL
+#ifdef WIN32
 #include <windows.h>
-// SOCKET
-typedef u_int	SOCKET;
-int PASCAL closesocket(SOCKET);
-#else
-#	if defined(WIN32)
-#		include <windows.h>
-#	else
-#		define closesocket close
-#	endif
+
+#ifdef CYGWIN
+typedef u_int SOCKET;
+extern "C" int PASCAL FAR closesocket(SOCKET);
+#endif
+
+#else // WIN32
+#define closesocket close
 #endif
 
 #ifndef DOXYGEN
