@@ -1,14 +1,14 @@
 /** @file
 	Parser: string class decl.
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_STRING_H
 #define PA_STRING_H
 
-static const char * const IDENT_STRING_H="$Date: 2010-10-16 22:24:20 $";
+#define IDENT_PA_STRING_H "$Id: pa_string.h,v 1.204 2012-05-28 10:33:18 moko Exp $"
 
 // includes
 #include "pa_types.h"
@@ -54,6 +54,7 @@ class VRegex;
 
 int pa_atoi(const char* str, const String* problem_source=0);
 double pa_atod(const char* str, const String* problem_source=0);
+unsigned int pa_atoui(const char *str, int base, const String* problem_source=0);
 
 /// this is result of pos functions which mean that substr were not found
 #define STRING_NOT_FOUND ((size_t)-1)
@@ -435,6 +436,10 @@ public:
 			return CORD_chr(body, offset, c);
 		}
 
+		size_t strrpbrk(const char* chars, size_t left, size_t right) const;
+
+		size_t rskipchars(const char* chars, size_t left, size_t right) const;
+
 		template<typename I>
 		int for_each(int (*f)(char c, I), I info) const {
 			return CORD_iter(body, (CORD_iter_fn)f, (void*)info);
@@ -554,6 +559,14 @@ public:
 
 	const char* untaint_and_transcode_cstr(Language lang, const Request_charsets *charsets) const;
 
+	bool is_not_just_lang() const {
+		return langs.opt.is_not_just_lang !=0;
+	}
+	
+	Language just_lang() const {
+		return langs.opt.lang;
+	}
+
 	/// puts pieces to buf
 	Cm serialize(size_t prolog_size) const;
 	/// appends pieces from buf to self
@@ -630,6 +643,20 @@ public:
 		const String& substr, 
 		size_t this_offset=0, Language lang=L_UNSPECIFIED) const;
 
+	size_t strrpbrk(const char* chars, size_t left=0) const {
+		return (length()) ? body.strrpbrk(chars, left, length()-1) : STRING_NOT_FOUND;
+	}
+	size_t strrpbrk(const char* chars, size_t left, size_t right) const {
+		return body.strrpbrk(chars, left, right);
+	}
+
+	size_t rskipchars(const char* chars, size_t left=0) const {
+		return (length()) ? body.rskipchars(chars, left, length()-1) : STRING_NOT_FOUND;
+	}
+	size_t rskipchars(const char* chars, size_t left, size_t right) const {
+		return body.rskipchars(chars, left, right);
+	}
+
 	void split(ArrayString& result, 
 		size_t& pos_after,
 		const char* delim, 
