@@ -25,6 +25,7 @@
 # include <stdarg.h>
 # include "cord.h"
 # include "ec.h"
+
 # define I_HIDE_POINTERS	/* So we get access to allocation lock.	*/
 				/* We use this for lazy file reading, 	*/
 				/* so that we remain independent 	*/
@@ -142,6 +143,7 @@ int CORD_cmp(CORD x, CORD y)
     
     if (y == CORD_EMPTY) return(x != CORD_EMPTY);
     if (x == CORD_EMPTY) return(-1);
+	if (x == y) return (0);
     if (CORD_IS_STRING(y) && CORD_IS_STRING(x)) return(strcmp(x,y));
     CORD_set_pos(xpos, x, 0);
     CORD_set_pos(ypos, y, 0);
@@ -222,10 +224,11 @@ int CORD_ncmp(CORD x, size_t x_start, CORD y, size_t y_start, size_t len)
     return(0);
 }
 
-char * CORD_to_char_star(CORD x)
+char * CORD_to_char_star(CORD x, size_t len)
 {
-    register size_t len = CORD_len(x);
-    char * result = GC_MALLOC_ATOMIC(len + 1);
+	char * result;
+    if(0 == len) len = CORD_len(x);
+    result = GC_MALLOC_ATOMIC(len + 1);
     
     if (result == 0) OUT_OF_MEMORY;
     CORD_fill_buf(x, 0, len, result);
@@ -245,11 +248,11 @@ CORD CORD_from_char_star(const char* s)
     return(result);
 }
 
-const char*  CORD_to_const_char_star(CORD x)
+const char*  CORD_to_const_char_star(CORD x, size_t len)
 {
     if (x == 0) return("");
     if (CORD_IS_STRING(x)) return((const char* )x);
-    return(CORD_to_char_star(x));
+    return(CORD_to_char_star(x, len));
 }
 
 char CORD_fetch(CORD x, size_t i)
@@ -355,10 +358,9 @@ size_t CORD_rchr(CORD x, size_t i, int c)
 /* and call CORD_ncmp whenever there is a partial match.		*/
 /* This has the advantage that we allocate very little, or not at all.	*/
 /* It's very fast if there are few close misses.			*/
-size_t CORD_str(CORD x, size_t start, CORD s)
+size_t CORD_str(CORD x, size_t start, CORD s, size_t xlen)
 {
     CORD_pos xpos;
-    size_t xlen = CORD_len(x);
     size_t slen;
     register size_t start_len;
     const char*  s_start;
@@ -375,7 +377,7 @@ size_t CORD_str(CORD x, size_t start, CORD s)
         s_start = s;
         slen = strlen(s);
     } else {
-        s_start = CORD_to_char_star(CORD_substr(s, 0, sizeof(unsigned long)));
+        s_start = CORD_to_char_star(CORD_substr(s, 0, sizeof(unsigned long), 0), 0);
         slen = CORD_len(s);
     }
     if (xlen < start || xlen - start < slen) return(CORD_NOT_FOUND);
@@ -415,6 +417,7 @@ void CORD_ec_flush_buf(CORD_ec x)
 
     if (len == 0) return;
     s = GC_MALLOC_ATOMIC(len+1);
+    if (s == 0) OUT_OF_MEMORY;
     memcpy(s, x[0].ec_buf, len);
     s[len] = '\0';
     x[0].ec_cord = CORD_cat_char_star(x[0].ec_cord, s, len);
@@ -433,9 +436,29 @@ char CORD_nul_func(size_t i, void * client_data)
     return((char)(unsigned long)client_data);
 }
 
+#ifdef CORD_CHARS_CACHE
+static char* cord_chars_cache[256][15]={0};
+#endif
+
 CORD CORD_chars(char c, size_t i)
 {
-    return(CORD_from_fn(CORD_nul_func, (void *)(unsigned long)c, i));
+	if (i>0 && i<16 /* SHORT_LIMIT */) {
+		register char* result;
+#ifdef CORD_CHARS_CACHE
+		if(cord_chars_cache[(unsigned char)c][i])
+			return((CORD) cord_chars_cache[(unsigned char)c][i]);
+#endif
+		result=GC_MALLOC_ATOMIC(i+1);
+		if(result==0) OUT_OF_MEMORY;
+		memset(result, c, i);
+		result[i] = '\0';
+#ifdef CORD_CHARS_CACHE
+		cord_chars_cache[(unsigned char)c][i]=result;
+#endif
+		return((CORD) result);
+	} else {
+		return(CORD_from_fn(CORD_nul_func, (void *)(unsigned long)c, i));
+	}
 }
 
 CORD CORD_from_file_eager(FILE * f)
