@@ -1,19 +1,20 @@
 /** @file
 	Parser: Method class decl.
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_METHOD_H
 #define PA_METHOD_H
 
-static const char * const IDENT_METHOD_H="$Date: 2010-11-09 00:08:45 $";
+#define IDENT_PA_METHOD_H "$Id: pa_method.h,v 1.20 2012-06-05 10:28:43 misha Exp $"
 
 #define OPTIMIZE_CALL
 #define OPTIMIZE_RESULT
 
 #include "pa_operation.h"
+#include "pa_vjunction.h"
 
 /**
 	native code method
@@ -130,6 +131,12 @@ public:
 	/// call this before invoking to ensure proper actual numbered params count
 	void check_actual_numbered_params(
 		Value& self, MethodParams* actual_numbered_params) const;
+
+	VJunction* get_vjunction(Value& aself) {
+		if(!junction_template)
+			return junction_template=new VJunction(aself, this);
+		return junction_template->get(aself);
+	}
 };
 
 ///	Auto-object used for temporarily substituting/removing elements
