@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b method_frame write context
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VMETHOD_FRAME_H
 #define PA_VMETHOD_FRAME_H
 
-static const char * const IDENT_VMETHOD_FRAME_H="$Date: 2010-11-08 23:53:46 $";
+#define IDENT_PA_VMETHOD_FRAME_H "$Id: pa_vmethod_frame.h,v 1.93 2012-06-08 11:44:02 misha Exp $"
 
 #include "pa_wcontext.h"
 #include "pa_vvoid.h"
@@ -111,18 +111,11 @@ public:
 	const String& as_string(int index, const char* msg) { 
 		return as_no_junction(index, msg).as_string();
 	}
-	/// handy hash ensurer
-	HashStringValue* as_hash(int index, const char* msg_no_junction=0, const char* msg_incorrect_type=0){
-		Value& voptions=as_no_junction(index, msg_no_junction ? msg_no_junction : OPTIONS_MUST_BE_HASH_NOT_CODE);
-		if(voptions.is_defined() && !voptions.is_string())
-			if(HashStringValue* options=voptions.get_hash())
-				return options;
-			else
-				throw Exception(PARSER_RUNTIME,
-					0,
-					msg_incorrect_type ? msg_incorrect_type : OPTIONS_MUST_BE_HASH);
-		return 0;
-	}
+	/// handy hash ensurers
+	HashStringValue* as_hash(int index, const char* name=0);
+	/// handy table ensurer
+	Table* as_table(int index, const char* name=0);
+
 private:
 
 	Value **felements;
@@ -272,8 +265,8 @@ public: // usage
 	}
 
 	void store_params(Value **params, size_t count) {
-		if(method.params_names) {
-			size_t param_count=method.params_names->count();
+		if(my) {
+			size_t param_count=method.params_names ? method.params_names->count():0;
 			size_t i=0;
 
 			if(count>param_count){
@@ -318,9 +311,13 @@ public: // usage
 	void empty_params(){
 		if(method.params_names){
 			size_t param_count=method.params_names->count();
-			for(size_t i=0; i<param_count; i++) {
-				const String& fname=*(*method.params_names)[i];
-				my->put(fname, VVoid::get());
+			if(param_count>0){
+				const String& fname=*(*method.params_names)[0];
+				my->put(fname, VString::empty());
+				for(size_t i=1; i<param_count; i++) {
+					const String& fname=*(*method.params_names)[i];
+					my->put(fname, VVoid::get());
+				}
 			}
 		}
 	}
