@@ -1,14 +1,14 @@
 /**	@file
 	Parser: @b object class decl.
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VOBJECT_H
 #define PA_VOBJECT_H
 
-static const char * const IDENT_VOBJECT_H="$Date: 2010-08-11 16:21:52 $";
+#define IDENT_PA_VOBJECT_H "$Id: pa_vobject.h,v 1.59 2012-05-28 19:47:52 moko Exp $"
 
 // includes
 
@@ -46,7 +46,7 @@ public: // Value
 	override VStateless_class *get_class() { return &fclass; }
 
 	override bool is_defined() const;
-	override Value& as_expr_result(bool);
+	override Value& as_expr_result();
 	override int as_int() const;
 	override double as_double() const;
 	override bool as_bool() const;
@@ -59,6 +59,8 @@ public: // Value
 	override Value* get_element(const String& aname);
 	override const VJunction* put_element(const String& name, Value* value, bool replace);
 
+	override const String* get_json_string(Json_options& options);
+
 	/// VObject default getter & setter support
 	override void enable_default_getter(){ state |= IS_GETTER_ACTIVE; }
 	override void enable_default_setter(){ if(fclass.has_default_setter()) state |= IS_SETTER_ACTIVE; }
