@@ -1,14 +1,14 @@
 /**	@file
 	Parser: @b string parser class decl.
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VSTRING_H
 #define PA_VSTRING_H
 
-static const char * const IDENT_VSTRING_H="$Date: 2010-10-24 21:41:43 $";
+#define IDENT_PA_VSTRING_H "$Id: pa_vstring.h,v 1.70 2012-05-28 19:47:52 moko Exp $"
 
 // includes
 
@@ -31,13 +31,9 @@ public: // Value
 	override bool as_bool() const { return as_double()!=0; }
 	/// VString: true
 	override bool is_string() const { return true; }
-	/// VString: fstring as VDouble or this depending on return_string_as_is
-	override Value& as_expr_result(bool return_string_as_is=false) { 
-		if(return_string_as_is)
-			return *this;
-		else
-			return *new VDouble(as_double());
-	}
+
+	/// VString: VDouble
+	override Value& as_expr_result() { return *new VDouble(fstring->as_double()); }
 	/// VString: fstring
 	override const String* get_string() { return fstring; };
 	/// VString: fstring
@@ -49,7 +45,7 @@ public: // Value
 	override VFile* as_vfile(String::Language lang, const Request_charsets *charsets=0);
 
 	/// VString: json string
-	override const String* get_json_string(Json_options*) { 
+	override const String* get_json_string(Json_options&) { 
 		String* result = new String();
 		result->append_quoted(fstring);
 		return result;
@@ -77,6 +73,11 @@ public: // usage
 	const String& string() const { return *fstring; }
 	void set_string(const String& astring) { fstring=&astring; }
 
+	inline static VString *empty(){
+		static VString singleton;
+		return &singleton;
+	}
+
 private:
 	const String* fstring;
 
