@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b table parser class decl.
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VTABLE_H
 #define PA_VTABLE_H
 
-static const char * const IDENT_VTABLE_H="$Date: 2010-11-03 22:08:45 $";
+#define IDENT_PA_VTABLE_H "$Id: pa_vtable.h,v 1.60 2012-05-28 19:47:53 moko Exp $"
 
 #include "pa_vstateless_object.h"
 #include "pa_table.h"
@@ -39,9 +39,9 @@ public: // Value
 	/// VTable: 0 or !0
 	override bool as_bool() const { return as_int()!=0; }
 	/// VTable: count
-	override Value& as_expr_result(bool /*return_string_as_is=false*/) { return *new VInt(as_int()); }
+	override Value& as_expr_result() { return *new VInt(as_int()); }
 	/// VTable: json-string
-	override const String* get_json_string(Json_options* options);
+	override const String* get_json_string(Json_options& options);
 	/// extract VTable
 	override Table* get_table() { return ftable; }
 	/// VTable: columns,methods
