@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b xdoc parser class decl.
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VXDOC_H
 #define PA_VXDOC_H
 
-static const char * const IDENT_VXDOC_H="$Date: 2009-08-08 13:30:22 $";
+#define IDENT_PA_VXDOC_H "$Id: pa_vxdoc.h,v 1.52 2012-06-21 14:22:10 moko Exp $"
 
 #include "classes.h"
 #include "pa_common.h"
@@ -24,6 +24,25 @@ static const char * const IDENT_VXDOC_H="$Date: 2009-08-08 13:30:22 $";
 
 extern Methoded* xdoc_class;
 
+struct XDocOutputOptions {
+	const String* method;       /* the output method */
+	const String* encoding;     /* encoding string */
+	const String* mediaType;    /* media-type string */
+	int indent;                 /* should output being indented */
+	const String* version;      /* version string */
+	int standalone;             /* standalone = "yes" | "no" */
+	int omitXmlDeclaration;     /* omit-xml-declaration = "yes" | "no" */
+	const String* filename;     /* Parser3 option: filename */
+
+	XDocOutputOptions() {
+		memset(this, 0, sizeof(*this));
+		indent=standalone=omitXmlDeclaration=-1;
+	};
+
+	void append(Request& r, HashStringValue* options, bool with_filename=false);
+};
+
+
 /// value of type 'xdoc'. implemented with libxml & co
 class VXdoc: public VXnode {
 public: // Value
@@ -37,7 +56,10 @@ public: // Value
 	override bool as_bool() const { return true; }
 
 	/// VXdoc: true	 
-	override Value& as_expr_result(bool /*return_string_as_is=false*/);
+	override Value& as_expr_result();
+
+	/// VFile: json-string
+	override const String* get_json_string(Json_options& options);
 
 	/// VXdoc: $CLASS,$method, fields
 	override Value* get_element(const String& aname);
@@ -92,20 +114,7 @@ public:
 
 	VHash search_namespaces;
 
-	struct Output_options {
-		const String* method;            /* the output method */
-		const String* encoding;          /* encoding string */
-		const String* mediaType;         /* media-type string */
-		int indent;                 /* should output being indented */
-		const String* version;           /* version string */
-		int standalone;             /* standalone = "yes" | "no" */
-		int omitXmlDeclaration;     /* omit-xml-declaration = "yes" | "no" */
-
-		Output_options() {
-			memset(this, 0, sizeof(*this));
-			indent=standalone=omitXmlDeclaration=-1;
-		};
-	} output_options;
+	XDocOutputOptions output_options;
 
 private:
 
