@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b xnode parser class decl.
 
-	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VXNODE_H
 #define PA_VXNODE_H
 
-static const char * const IDENT_VXNODE_H="$Date: 2009-08-08 13:30:22 $";
+#define IDENT_PA_VXNODE_H "$Id: pa_vxnode.h,v 1.42 2012-05-23 16:26:41 moko Exp $"
 
 #include "classes.h"
 #include "pa_common.h"
@@ -41,7 +41,7 @@ public: // Value
 	override bool as_bool() const { return true; }
 
 	/// VXnode: true	 
-	override Value& as_expr_result(bool /*return_string_as_is=false*/);
+	override Value& as_expr_result();
 
 	/// VXnode: $CLASS,$method, fields
 	override Value* get_element(const String& aname);
